<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>הוספת תוספים</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>חיפוש:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>הוספת וידג׳ט</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(רק מופע אחד יכול לרוץ בכל פעם)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>הגדרת לוח</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>לוח</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>וידג׳טים</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>הגדרת לוח</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;ערך פיקסלים שלילי מגדיר את אורך הלוח לכמות כזאת של פיקסלים מתחת לשטח הזמין במסך.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;למשל: „אורך” שומגדר ל־‎-100 פיקסלים, אם גודל המסך הוא 1000 פיקסלים, אז אורך הלוח יהיה 900 פיקסלים.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>אורך:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>פיקסלים</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> פיקסלים</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>גודל סמלים:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>יישור ומיקום</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>הסתרה &amp;אוטומטית</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>אפס משבית את ההנפשה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> מ״ש</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>אפס משבית את ההמתנה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>הצגה עם המתנה:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>גבול דק גלוי ללוח נסתר</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="337"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>לא לאפשר לחלונות מוגדלים לחתור תחת חלון הלוח</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="340"/>
        <source>Reserve space on display</source>
        <translation>שמירת מקום בתצוגה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>מיקום:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>משך הנפשה:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>יישור:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation>שורות:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="211"/>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <location filename="../config/configpanelwidget.cpp" line="218"/>
        <source>Center</source>
        <translation>מרכז</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="356"/>
        <source>Custom styling</source>
        <translation>סגנון בהתאמה אישית</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="377"/>
        <source>Font color:</source>
        <translation>צבע גופן:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="417"/>
        <source>Background color:</source>
        <translation>צבע רקע:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="456"/>
        <source>Background opacity:</source>
        <translation>אטימות רקע:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="488"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;נדרש ניהול חלונות להגדרת שקיפות לוח.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="516"/>
        <source>Background image:</source>
        <translation>תמונת רקע:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="568"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>מעקף חלקי לסגנונות וידג׳טים שלא יכולים
להשתמש בערכת עיצוב שונה ללוח.

אולי עדיף גם להשבית את:

הגדרות המראה של LXQt ←
ערכות סמלים ←
צביעת סמלים בסגנון וידג׳ט (ערכת צבעים)</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="578"/>
        <source>Override icon &amp;theme</source>
        <translation>שכתוב על &amp;ערכת סמלים</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="593"/>
        <source>Icon theme for panels:</source>
        <translation>ערכת סמלים ללוחות:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="177"/>
        <source>Top of desktop</source>
        <translation>למעלה בשולחן העבודה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="178"/>
        <source>Left of desktop</source>
        <translation>שמאל שולחן העבודה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="179"/>
        <source>Right of desktop</source>
        <translation>ימין שולחן העבודה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="180"/>
        <source>Bottom of desktop</source>
        <translation>תחתית שולחן העבודה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="189"/>
        <source>Top of desktop %1</source>
        <translation>למעלה בשולחן העבודה %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="190"/>
        <source>Left of desktop %1</source>
        <translation>שמאל שולחן העבודה %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="191"/>
        <source>Right of desktop %1</source>
        <translation>ימין שולחן העבודה %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="192"/>
        <source>Bottom of desktop %1</source>
        <translation>תחתית שולחן העבודה %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="217"/>
        <source>Top</source>
        <translation>למעלה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="219"/>
        <source>Bottom</source>
        <translation>תחתית</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="439"/>
        <location filename="../config/configpanelwidget.cpp" line="455"/>
        <source>Pick color</source>
        <translation>בחירת צבע</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="473"/>
        <source>Pick image</source>
        <translation>בחירת תמונה</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="473"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>תמונות ‎(*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>הגדרת תוספים</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>לתשומת לבך: אין אפשרות לאפס את ההגדרות שנערכו במסך הזה.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>העברה מעלה</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>העברה מטה</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>הסרה</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>הגדרה</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1130"/>
        <location filename="../lxqtpanel.cpp" line="1156"/>
        <source>Panel</source>
        <translation>לוח</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1159"/>
        <source>Configure Panel</source>
        <translation>הגדרת לוח</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1164"/>
        <source>Manage Widgets</source>
        <translation>ניהול וידג׳טים</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1170"/>
        <source>Add New Panel</source>
        <translation>הוספת לוח חדש</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1177"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>הסרת לוח</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1182"/>
        <source>Lock This Panel</source>
        <translation>נעילת הלוח הזה</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1338"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>הסרת לוח</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1339"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>לא ניתן לבטל הסרת לוח.
להסיר את הלוח?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="436"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>הגדרת „%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="441"/>
        <source>Move &quot;%1&quot;</source>
        <translation>העברת „%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="449"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>הסרת „%1”</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>שימוש בקובץ הגדרות חלופי.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>קובץ הגדרות</translation>
    </message>
</context>
</TS>
